%
% data loader
%
clear all
base_dir1 = '..\';
addpath(genpath(base_dir1));
addpath([base_dir1,'src\']);
addpath([base_dir1,'src\iris\']);
addpath([base_dir1,'src\lesage\']);
base_dir  = '.\';
cd(base_dir);

% diary
delete('.\data_setup.out');
diary('.\data_setup.out');
disp(' ');

% data files  
data_string = ['pwt70_w_country_names'];
data_file = [data_string,'.xlsx'];    % excel data file, download date as in filename
data_file = [base_dir data_file];
disp([' ']);
disp(['data loader']);
disp([' ']);
disp(['current date: ' datestr(clock,31)]);
disp(['current directory: ', pwd]);
disp(['data file: ', data_file]);

% rows for all time series
data_rows = [2, 11401];
names_col = [1, 1];

% load raw country names (only 1st col for dates)
names_col = {'a','b'};
[names_mat2,names_mat] = xlsread(data_file,'Tabelle1', ...
    [ num2str(names_col{1,1}), num2str(data_rows(1,1)), ':', num2str(names_col{1,2}), num2str(data_rows(1,2)) ]); 
names_country_tn_raw = names_mat(:,1);
names_country = unique(names_mat(:,1));
names_country_short = unique(names_mat(:,2));
n_countries_raw = size(names_country,1);
%disp([char(names_country),char(names_country_short)]);

% countries in kow (2003) aer
[names_mat2,names_mat_sel] = xlsread('names_kow.xlsx','Tabelle1','a1:a60'); 
names_country_sel = unique(names_mat_sel(:,1));
n_countries_sel = size(names_country_sel,1);
%disp(names_country_sel);

% year: years, col c
[year,names_mat2] = xlsread(data_file,'Tabelle1',['c2:c',num2str(data_rows(1,2))]); 

% gdp: rgdpeqa, col ae 
[gdp,names_mat2] = xlsread(data_file,'Tabelle1',['d2:ak',num2str(data_rows(1,2))]); 
index_gdp = 31-3;
gdp = gdp(:,index_gdp);
%disp([year,gdp]);
tn = size([year,gdp],1);
if tn ~= size(names_country_tn_raw,1)
    disp('matrix sizes do not match!');
    return
end
n_obs = 2009-1950+1;
if tn ~= n_obs*n_countries_raw
    disp('download matrix size do not match to raw obs and country numbers!');
    return
end

% collect data
data.year = [1950:2009]';
data.gdp = [];
data.country_name = {};
data.country_name_short = {};
elim_country_name = {};
for i=1:n_countries_sel
    country_sel = names_country_sel{i,1};
    index_country = strmatch(country_sel,names_country_tn_raw);
    if ~isempty(index_country)
        %disp(country_sel);
        %disp(index_country);
        year_sel = year(index_country,1);
        gdp_sel = gdp(index_country,1);
        data.country_name = [ data.country_name, country_sel ];
        data.country_name_short = [ data.country_name_short, country_sel ];
        data.gdp = [ data.gdp,gdp_sel ];
    else
        elim_country_name = [elim_country_name,country_sel];
    end
    %disp([num2str(year_sel,'%5.0f'),num2str(blanks(size(year_sel,1)))',num2str(gdp_sel,'% 6.2f')]);
    %pause
end
disp(' ');
disp(data.country_name);
disp(data.gdp);
disp('no obs for countries at all:');
disp(char(elim_country_name));

% eliminate series with nan at the year 1960
index_1960 = 11;
index_nan = isnan(data.gdp(index_1960,:));
elim_country_name = [elim_country_name,data.country_name(1,index_nan)];
index_sel_new = ~index_nan;
data.year_new = data.year(index_1960:end,1);
data.gdp_new = data.gdp(index_1960:end,index_sel_new);
data.country_name_new = data.country_name(1,index_sel_new);
data.country_name_short_new = data.country_name_short(1,index_sel_new);
disp(data.country_name_new);
disp(data.gdp_new);
n_countries_sel = size(data.country_name_new,2);
t_sel = size(data.year_new,1);

%
disp(' ');
disp('no obs for countries at all or not including 1960:');
disp(char(elim_country_name));
disp(' ');
disp(['remaining countries: ',num2str(n_countries_sel)]);
disp(data.country_name_new);
disp(['annual observations: ',num2str(t_sel)]);
disp(' ');
disp(data)

% log diff gdp
data.gdp_new = log(data.gdp_new(2:end,:)./data.gdp_new(1:end-1,:))*100.0;
data.year_new = data.year_new(2:end,:);

figure; newplot;
plot(data.gdp_new');

%
data.dates = data.year_new;
data.data_fin = data.gdp_new;
data.name_ser = data.country_name_new;
data.name_ser_group = {};
data.name_ser_group = [ data.name_ser_group, ...
    'Latin America'    'Oceania'    'Europe'    'Asia 1'    'Europe'    'Latin America' ...
    'Latin America'    'Africa'    'North America'    'Latin America'    'Latin America'    'Latin America' ...
    'Europe'    'Latin America'    'Latin America'    'Europe'    'Europe'    'Europe'  'Europe' ...
    'Latin America'    'Latin America'    'Asia 2'    'Europe'    'Asia 1'    'Asia 1' ...
    'Europe'    'Europe'    'Latin America'    'Asia 2'    'Africa'    'Asia 2'    'Europe' ...
    'Asia 2'    'North America'    'Africa'    'Europe'    'Oceania'    'Europe' ...
    'Asia 1'    'Latin America'    'Latin America'    'Latin America'    'Asia 1'    'Europe' ...
    'Africa'    'Asia 2'    'Africa'    'Europe'    'Asia 1'    'Europe' ...
    'Europe'    'Asia 2'    'Europe'    'North America'    'Latin America' ...
    'Latin America'    'Africa' ];
disp([data.name_ser; data.name_ser_group]);

data.name_short = data.country_name_short_new;
data = rmfield(data,{'year_new','gdp_new','country_name_new','country_name_short_new','country_name','country_name_short'});
disp(' ');
disp(data)

%
% store
%
str = ([base_dir data_string '.mat']);
save(str,'data');

% diary
diary off;
disp(' '); 

return
