clear all
close all
rng default 

prepare_pathsmodels

% loop evaluation of relevance and irrelevance
n_mod=size(modparam_mat,2);
for i=1:n_mod
    disp(' ');
    disp(['model ',num2str(i),' out of ',num2str(n_mod)]);
    modparam=modparam_mat(i).modparam;
    % load estimation results
    nf=modparam.nf;prior=modparam.prior;s0=modparam.s0;utz=modparam.utz;
    res_string=['results','_k',num2str(nf),'_prior',num2str(prior), ...
                '_s',num2str(s0*100,'%03.0f'),'_utz',num2str(utz),'_final'];
    disp(res_string);
    folder_load='.\results_final\'; % folder for prepared draws
    str=([folder_load,res_string]);
    load(str,'results');
    lamdraws=results.lamstarmc;
    fdraws=results.fstarmc;
    folder_save='.\results_eval_relevance\'; % folder to store results
    % evaluate relevance 
    it_sel=1:size(lamdraws,3);
    results_eval_draws=f_eval_relevance(data,modparam,lamdraws,fdraws,it_sel,folder_save);
    results_eval(i).results_eval_draws=results_eval_draws;
    results_eval(i).modparam=modparam;
    close all
    clear results modparam results_eval_draws
end
save results_eval

load results_eval
results_eval_cons=[results_eval.results_eval_draws];

% summary stats
stat_summary_hpd=[results_eval_cons.stat_hpd];
stat_summary_mhpd=[results_eval_cons.stat_mhpd];
stat_summary_col=[results_eval_cons.stat_col];
stat_labels=results_eval_cons(1,1).stat_labels;
group_labels=results_eval(1,2).results_eval_draws.group_names_unique';
statgroup_labels=[stat_labels;group_labels];
%
disp(' ');
disp('hpd group stats:');
disp(' ');
statgroup=[];digs=2;
for i=1:n_mod
    stat_summary=num2str(stat_summary_hpd(:,i),['%10.',num2str(digs),'f']);
    stat_group=results_eval(1,i).results_eval_draws.n_group_str_hpd;
    statgroup=[statgroup,strjust(char(stat_summary,stat_group),'right')];
end
disp([char(statgroup_labels),blanks(size(char(statgroup_labels),1))',statgroup]);
%
disp(' ');
disp('mhpd summary stats:');
disp(' ');
statgroup=[];
for i=1:n_mod
    stat_summary=num2str(stat_summary_mhpd(:,i),['%10.',num2str(digs),'f']);
    stat_group=results_eval(1,i).results_eval_draws.n_group_str_mhpd;
    statgroup=[statgroup,strjust(char(stat_summary,stat_group),'right')];
end
disp([char(statgroup_labels),blanks(size(char(statgroup_labels),1))',statgroup]);
%
disp(' ');
disp('col summary stats:');
disp(' ');
statgroup=[];
for i=1:n_mod
    stat_summary=num2str(stat_summary_col(:,i),['%10.',num2str(digs),'f']);
    stat_group=results_eval(1,i).results_eval_draws.n_group_str_col;
    statgroup=[statgroup,strjust(char(stat_summary,stat_group),'right')];
end
disp([char(statgroup_labels),blanks(size(char(statgroup_labels),1))',statgroup]);

% latex
method_str_vec={'hpd','mhpd','col'};
n_methods=size(method_str_vec,2);
for j=1:n_methods
    tab_show={};
    for i=1:n_mod
        if j==1; stat_summary=stat_summary_hpd; n_group_str_i=results_eval(1,i).results_eval_draws.n_group_str_hpd; end
        if j==2; stat_summary=stat_summary_mhpd; n_group_str_i=results_eval(1,i).results_eval_draws.n_group_str_mhpd; end
        if j==3; stat_summary=stat_summary_col; n_group_str_i=results_eval(1,i).results_eval_draws.n_group_str_col; end
        if i==1
            tab_show(1,1)=cellstr(blanks(1));
            tab_show(2,1)=cellstr(blanks(1));
            tab_show(3,1)=cellstr(blanks(1));
            tab_show=[tab_show;statgroup_labels];
        end
        % header with blanks above and below
        tab_show_col=cellstr(blanks(1));
        tab_show_col=[tab_show_col;cellstr(['variant ',num2str(i)])];
        tab_show_col=[tab_show_col;cellstr(blanks(1))];
        % utz
        if stat_summary(1,i)==0
            cell_str='-';
        elseif stat_summary(1,i)==1
            cell_str='Geweke, Zhou (1996)';
        end
        tab_show_col=[tab_show_col;cellstr(cell_str)];
        tab_show_col=[tab_show_col;cellstr(num2str(stat_summary(2,i),'%10.2f'))]; % s0
        tab_show_col=[tab_show_col;cellstr(num2str(stat_summary(3,i),'%10.0f'))]; % nf
        if stat_summary(4,i)==0
            cell_str='normal';
        elseif stat_summary(4,i)==1
            cell_str='one-layer';
        elseif stat_summary(4,i)==2
            cell_str='two-layer';
        end
        tab_show_col=[tab_show_col;cellstr(cell_str)]; % prior
        stat_summary_str=num2str(stat_summary(5:6,i),['%10.',num2str(digs),'f']); % pct (rel vars, sign lam)
        tab_show_col=[tab_show_col;cellstr(strtrim(stat_summary_str))];
        tab_show_col=[tab_show_col;cellstr(strtrim(n_group_str_i))];
        tab_show(1:size(tab_show_col,1),end+1)=tab_show_col;
    end
    tab_show(end+1,1)=cellstr(blanks(1));
    disp(tab_show);
    tablename=['empirical results: ',str_name_out,' relevance stats (based on ',method_str_vec{1,j},')'];
    savename=[folder_save,'table_',str_name_out,'_relevance_',method_str_vec{1,j},'.tex'];
    f_cell2swp(tab_show,savename,tablename);
end
