clear all
close all
dbstop if error
prepare_pathsmodels

% loop evaluation and col change
tstart=tic;
n_mod=size(modparam_mat,2);
for i=1:n_mod
    disp(' ');
    disp(['model ',num2str(i),' out of ',num2str(n_mod)]);
    modparam=modparam_mat(i).modparam;
    % load estimation results
    nf=modparam.nf;prior=modparam.prior;s0=modparam.s0;utz=modparam.utz;
    res_string=['results','_k',num2str(nf),'_prior',num2str(prior), ...
                '_s',num2str(s0*100,'%03.0f'),'_utz',num2str(utz)];
    disp(res_string);
    str=([base_dir 'results\',res_string]);
    load(str,'results');
    lamdraws=results.lamstarmc;
    fdraws=results.fstarmc;
    % folder_save: path to store new draws
    folder_save='.\results_final\';
    if not(exist(folder_save,'dir')==7)
        mkdir(folder_save);
    end
    % kmedoids clustering, keep only permutations of original ordering,
    % watch out the number of draws! k-medoids will fail with n_it>10k!
    clust_flag='on';
    if strcmp(clust_flag,'on')
        n_it=min(10000,size(lamdraws,3)); 
        it_sel=size(lamdraws,3)-n_it+1:size(lamdraws,3);
        lamdraws_base=lamdraws(:,:,it_sel);
        fdraws_base=fdraws(:,:,it_sel);
        [lamstarmc_out,fstarmc_out]=f_colchange_fbased(lamdraws_base,fdraws_base,nf);
        n_it_clust=size(lamstarmc_out,3);
        n_it=n_it_clust;
        disp(['draws after clust ',num2str(n_it_clust)]);
        legend_str_vec=cell(1,nf);
        % final sign switch sign
        lamstarm=median(lamstarmc_out,3);
        s_ind=f_checkpositivity(lamstarm);
        for j=s_ind
            lamstarmc_out(:,j,:)=-lamstarmc_out(:,j,:);
            fstarmc_out(:,j,:)=-fstarmc_out(:,j,:);
        end
        lamdraws=lamstarmc_out;
        fdraws=fstarmc_out;
        results.lamstarmc=lamdraws; % over write old draws in results struct
        results.fstarmc=fdraws;
    end
    % sequential correlation clustering based on factor time-series
    % patterns by sylvia
    clust_flag='off';
    if strcmp(clust_flag,'on')
        % case-specific clustering
        if i==1
            n_it=min(10000,size(lamdraws,3)); 
            it_sel=size(lamdraws,3)-n_it+1:size(lamdraws,3);
            lamdraws_base=lamdraws(:,:,it_sel);
            fdraws_base=fdraws(:,:,it_sel);
            [fstarmc_out,lamstarmc_out,it_sel]=f_identify_factors_new(fdraws_base,lamdraws_base,prior);
            n_it_clust=size(it_sel.in,2);
            n_it=n_it_clust;
            disp(['draws after clust ',num2str(n_it_clust)]);
            fstarmc_out=fstarmc_out(:,:,it_sel.in);
            lamstarmc_out=lamstarmc_out(:,:,it_sel.in);
            nf_clust=size(fstarmc_out,2);
            if nf_clust~=nf
                disp(['warning: nf_clust ',num2str(nf_clust),', nf ',num2str(nf)]);
            end
            lamdraws=lamstarmc_out;
            fdraws=fstarmc_out;
            results.lamstarmc=lamdraws; % over write old draws in results struct
            results.fstarmc=fdraws;
        else
            % rest of models
            n_it=min(2000,size(lamdraws,3)); 
            it_sel=size(lamdraws,3)-n_it+1:size(lamdraws,3);
            lamdraws_base=lamdraws(:,:,it_sel);
            fdraws_base=fdraws(:,:,it_sel);
            [fstarmc_out,lamstarmc_out,it_sel]=f_identify_factors_new(fdraws_base,lamdraws_base,prior);
            n_it_clust=size(it_sel.in,2);
            n_it=n_it_clust;
            disp(['draws after clust ',num2str(n_it_clust)]);
            fstarmc_out=fstarmc_out(:,:,it_sel.in);
            lamstarmc_out=lamstarmc_out(:,:,it_sel.in);
            nf_clust=size(fstarmc_out,2);
            if nf_clust~=nf
                disp(['warning: nf_clust ',num2str(nf_clust),', nf ',num2str(nf)]);
            end
            lamdraws=lamstarmc_out;
            fdraws=fstarmc_out;
            results.lamstarmc=lamdraws; % over write old draws in results struct
            results.fstarmc=fdraws;
            % sign change
            it_sel2=1:size(fdraws,3);
            it_sel=size(lamdraws,3)-n_it+1:size(lamdraws,3);
            lamdraws_base=lamdraws(:,:,it_sel2);
            fdraws_base=fdraws(:,:,it_sel2);
            disp(' ');
            disp('correcting signs ...');
            [lamdraws,fdraws]=f_signchange(lamdraws_base,fdraws_base,'on','fig_temp','.\');
            disp('sign change done');
        end
        close all
    end
    % save new draws under folder_save
    res_string=['results','_k',num2str(nf),'_prior',num2str(prior), ...
                '_s',num2str(s0*100,'%03.0f'),'_utz',num2str(utz),'_final'];
    str=([folder_save,res_string]);
    save(str,'results');
    clear results modparam
end

elt=toc(tstart)/(60*60);
disp(' ');
disp(['elapsed time for clustering ',num2str(elt),' hours']);
