function ser_new = f_makestat(ser_in,trafo)
%
% makes time series stationary by differencing
%
% ser_in    (Tx1) vector of observations
% trafo     scalar for method
% standard  = 1, mean 0, var 1 standardising, else nothing
%
% test: 
% ser_test = [NaN; NaN; NaN; -1.0; 2.1; 3; 4.2; NaN]; ser_out = f_makestat(ser_test,1,1); [ser_out, ser_test]
%
% C Schumacher, 28 Nov 2005
%

% unchanged
if (trafo==1)
    ser_new = ser_in;
end

% 1st differencing, no logs
if (trafo==2)
    ser_new = ser_in(2:size(ser_in,1),:)-ser_in(1:size(ser_in,1)-1,:);
    ser_new = [NaN; ser_new];
end

% 2nd differencing, no logs
if (trafo==3)
    ser_new = ser_in(2:size(ser_in,1),:)-ser_in(1:size(ser_in,1)-1,:);
    ser_new = ser_new(2:size(ser_new,1),:)-ser_new(1:size(ser_new,1)-1,:);
    ser_new = [NaN; NaN; ser_new];
end

% only logs
if (trafo==4)
    ser_in = f_intcorrect(ser_in);
    ser_new = log(ser_in);
end

% 1st differencing, logs
if (trafo==5)
    ser_in = f_intcorrect(ser_in);
    ser_new = log(ser_in(2:size(ser_in,1),:))-log(ser_in(1:size(ser_in,1)-1,:));
    ser_new = [NaN; ser_new];
end

% 2nd differencing, logs
if (trafo==6)
    ser_in = f_intcorrect(ser_in);
    ser_new = log(ser_in(2:size(ser_in,1),:))-log(ser_in(1:size(ser_in,1)-1,:));
    ser_new = ser_new(2:size(ser_new,1),:)-ser_new(1:size(ser_new,1)-1,:);
    ser_new = [NaN; NaN; ser_new];
end

% 1st differencing of annual log change, de mol et al. (2008) jectrcs
if (trafo==7)
    ser_in = f_intcorrect(ser_in);
    ser_new = log(ser_in(1+12:size(ser_in,1),:))-log(ser_in(1:size(ser_in,1)-12,:));
    ser_new = ser_new(2:size(ser_new,1),:)-ser_new(1:size(ser_new,1)-1,:);
    ser_new = [NaN(13,1); ser_new];
end

% annual log change, de mol et al. (2008) jectrcs
if (trafo==8)
    ser_in = f_intcorrect(ser_in);
    ser_new = log(ser_in(1+12:size(ser_in,1),:))-log(ser_in(1:size(ser_in,1)-12,:));
    ser_new = [NaN(12,1); ser_new];
end

return
