function [ftmcstar_out,lamstarmc_out,it_sel]= f_permute_factors_new(ftmcstar,lamstarmc,ftstmed,prior)
% factor model identification according to identified factor patterns (run identify_factors_new before)
% 1. correlate the draws with the identified factor pattern, permute accordingly factor-specific parameters and perform sign-identification
%    (i) keep those draws in it_sel.in which are uniquely assigned to the factor patterns based on maximum correlation with factor patterns
%    (ii) permute all factor-specific (loadings etc.) parameters according to the assignment of the factor draws to the factor patterns
%    (iii) switch the sign of factor draws and factor-specific parameters which are negatively correlated with the assigned factor patterns 
% 2. perform overall sign switch, to achieve a majority of positive factor loadings 
% 3. rank the factors in descending order of the number of non-zero factor loading
nf=size(lamstarmc,2);
MMC=size(lamstarmc,3);

it_sel=struct([]);
it_sel(1).out=[];
it_sel(1).in=[];
nm=size(ftstmed,2);

% 1. correlate the draws with the identified factor pattern, permute accordingly factor-specific parameters and perform sign-identification
for mc=1:MMC;
    co_mat=corr(ftstmed,ftmcstar(:,:,mc));
    co_max=max(abs(co_mat),[],1);
    ind_co=(abs(co_mat)==kron(ones(nm,1),co_max));
    [si,r]=find(ind_co');
    co_sign=sign(co_mat(ind_co));
    co_sign=co_sign(si);
    ind_sig=find(co_sign<0);
    % (i) keep those draws in it_sel.in which are uniquely assigned to the factor patterns based on maximum correlation with factor patterns
    if any([sum(ind_co,1) sum(ind_co,2)']>1) 
        it_sel(1).out(end+1)=mc;
        % disp(co_max); disp(['out ',num2str(mc)]);
    else
        it_sel(1).in(end+1)=mc; 
        %disp(co_max); disp(['in ',num2str(mc)]);
        % (ii) permute all factor-specific (loadings etc.) parameters according to the assignment of the factor draws to the factor patterns
        lamstarmc(:,:,mc)=lamstarmc(:,si,mc);
        ftmcstar(:,:,mc)=ftmcstar(:,si,mc);
        % (iii) switch the sign of factor draws and factor-specific parameters which are negatively correlated with the assigned factor patterns         
        if any(ind_sig)
            lamstarmc(:,ind_sig,mc)=-lamstarmc(:,ind_sig,mc);
            ftmcstar(:,ind_sig,mc)=-ftmcstar(:,ind_sig,mc);
        end
    end
    %pause
end
%pause
% 2. perform overall sign switch, to achieve a majority of positive factor loadings 
lamstarm=median(lamstarmc(:,:,it_sel(1).in),3);
s_ind=f_checkpositivity(lamstarm);
for j=s_ind
    lamstarmc(:,j,:)=-lamstarmc(:,j,:);
    ftmcstar(:,j,:)=-ftmcstar(:,j,:);
end

% 3. rank the factors in descending order of the number of non-zero factor loading
if prior>0
    [~,si]=sort(sum(lamstarm~=0),'descend');
    lamstarmc=lamstarmc(:,si,:);
    ftmcstar=ftmcstar(:,si,:);
end

lamstarmc_out=lamstarmc;
ftmcstar_out=ftmcstar;

end