clear all
close all
rng default 
dbstop if error
poolobj = gcp('nocreate');
delete(poolobj);

prepare_pathsdgpsmodels

% generate folder and for results
folder='.\results\';
if not(exist(folder,'dir')==7)
    mkdir(folder);
end

tstart=tic;
parpool(50);
for s0_index=1:length(s0_dgp_vec)
    s0_sim=s0_dgp_vec(s0_index);
    disp(' ');
    disp(['s0 ',num2str(s0_sim)]);
    disp(' ');
    parfor rep=1:n_rep
        rho0_sim=kron(ones(nf_sim,1),[30,s0_sim]); %rho0_1=precision, rho0_2=mean
        disp([' rep ',num2str(rep),' from ',num2str(n_rep)]);
        % 
        % load data based on s0
        dgp_spec=struct('N_sim',N_sim,'T_sim',T_sim,'T0_sim',T0_sim,'nf_sim',nf_sim, ...
            'philag_sim',philag_sim,'psilag_sim',psilag_sim,'rho0_sim',rho0_sim);
        load_str=['datasim_s',num2str(s0_sim*100,'%03.0f'),'_rep',num2str(rep)];
        loadname=['.\data\',load_str]';
        datasim2=load(loadname,'datasim');
        xt=datasim2.datasim.xt;
        lamspar_index_true=datasim2.datasim.lamspar_index_true;
        datasim2=[];
        %
        % estimation with: different a) priors, b) factors
        for prior_index=1:n_prior
            prior=prior_est_vec(1,prior_index); % prior on factor loadings: 0: normal (hierarchical); 1: one-layer sparse; 2:two-layer sparse;
            for nf_index=1:nf_maxindex 
                data=[];
                nf=nf_vec(1,nf_index);
                disp(['  s0 ' num2str(s0_sim,'%4.2f') ', rep ' int2str(rep) ', prior ' int2str(prior) ', nf ' int2str(nf)]);
                % setup_params_estimation
                it=6000;
                it0=2000; 
                rth=2; % save every rth draw
                philag=1; % autocorrelation length of common factor
                psilag=0; % autocorrelation length of idiosyncratic component
                bf=0; %flag to retain the posterior moments of the model parameters
                const=0; %flag to include a constant
                f_ind=0;
                m_adj=0; %flag to demean data
                s_adj=0; %flag to standardize data (implemented only with m_adj=1 together)
                normp=0; %flag to use 'switching' algorithm (sampling f_t based on lambda'lambda=I)
                utz=0; %flag to impose upper triangular zero loadings (only in combination with norm=0)
                % collect params
                s0_est=0.50; % use this s0 for estimation!
                modparam=struct('it',it,'it0',it0,'rth',rth,'nf',nf,'s0',s0_est, ...
                    'prior',prior,'philag',philag,'psilag',psilag,'utz',utz, ...
                    'f_ind',f_ind,'bf',bf,'const',const,'m_adj',m_adj,'s_adj',s_adj,'normp',normp);
                data.data_fin=xt;data.name_ser=[];data.name_ser_group=[];
                results=f_estimate_sparfac(data,modparam);
                % store results container
                res_string=['results','_k',num2str(nf),'_prior',num2str(prior), ...
                            '_s',num2str(s0_sim*100,'%03.0f'),'_utz',num2str(utz),'_rep',num2str(rep)];
                str=([folder,res_string]);
                f_save(str,results);
                results=[];
            end
        end
    end    
end
poolobj = gcp('nocreate');
delete(poolobj);

elt=toc(tstart)/(60*60);
disp(' ');
disp(['elapsed estimation time ',num2str(elt),' hours']);


