function [C,F] = f_factor_estimate(Xm,r)
%
% function:
%   [C,F] = f_factor_estimate(Xm,r)
%
% aim:
%   estimates data according to factor model using PCA proposed by 
%   Stock/Watson (2002) JBES. Computes data as common component of 
%   factor model. 
%
% output:
%   C             (Tm x Nm) estimate of common components
%   F             (Tm x r) estimate of PCA factors
%
% input:
%   Xm            (Tm x Nm) data matrix for monthly data, must not contain 
%                           missings
%   r		  	  no. of static factors
%
% C. Schumacher, 29 Jul 2005
%


% estimate factor
X = Xm; 

% factors, no of factors equal to r
options.disp = 0;
[evec,eval] = eigs(cov(X),r,'lm',options);
F = X*evec; % F = F./sqrt(var(F)); F = F*(-1.0);

% common component by OLS
C = F*inv(F'*F)*(F'*X); %C = F*evec';

return
