function results=f_eval_draws(modparam,lamdraws,fdraws,it_sel,folder,flag_longsmall,rep)    

if nargin<7
    rep=nan;
end
if nargin<6 || strcmp(flag_longsmall,'small') 
    flag_longsmall='small';
end

% generate folder and for results
if not(exist(folder,'dir')==7)
    mkdir(folder);
end

% get model specification
disp(' ');
disp('model specification');
disp(modparam);
param_str_vec={'it','it0','rth','nf','s0','prior','philag','psilag',...
               'utz','f_ind','bf','const','m_adj','s_adj','normp'};
for i=1:size(param_str_vec,2)
    param_str=param_str_vec{1,i};
    eval([param_str,'=','modparam.',param_str,';']);
end
results.modparam=modparam;

% string representing key model specifications
if isnan(rep)
    modspec_string=['spec','_k',num2str(nf),'_prior',num2str(prior), ...
                    '_s',num2str(s0*100,'%03.0f'),'_utz',num2str(utz)];
else
    modspec_string=['spec','_k',num2str(nf),'_prior',num2str(prior), ...
                    '_s',num2str(s0*100,'%03.0f'),'_utz',num2str(utz),'_rep',num2str(rep)];
end

% diary
diary([folder,'diary_eval_draws',modspec_string,'.txt']);

% check
if size(lamdraws,3)~=size(fdraws,3)
    error('lamdraws and fdraws contain different numbers of draws')
end
it_raw=1:size(lamdraws,3);
if not(isempty(setdiff(it_sel,it_raw)))
    error('it_sel is not a subset of it_raw')
end
n_it=size(it_sel,2);
disp(' ');
disp(['number of draws ',num2str(n_it)]);

% check and correct sign change
lamdraws_base=lamdraws(:,:,it_sel);
fdraws_base=fdraws(:,:,it_sel);
flag_signchange='off'; % already done in kmedoids clust
if (strcmp(flag_signchange,'on'))
    disp(' ');
    disp('correcting signs ...');
    [lamdraws,fdraws]=f_signchange(lamdraws_base,fdraws_base,'on',['fig_',modspec_string],folder);
    disp('sign change done');
end
results.lamdraws_base=lamdraws_base;
results.fdraws_base=fdraws_base;
T=size(fdraws_base,1);
N=size(lamdraws_base,1);

% figure/table labels no factors 1:nf
legend_str_vec=cell(1,nf);
for nf_index=1:nf
    legend_str_vec(1,nf_index)={['col ',num2str(nf_index)]};
end

%
% figures: few selected lam, f over draws
%
flag_fig='on';
if strcmp(flag_fig,'on')
if strcmp(flag_longsmall,'huge')
    figure;newplot;
    i_sel=round(N*1/4); % cross section index for lam(i_sel,nf) with factor nf to be plotted
    lamdraws_i=squeeze(lamdraws(i_sel,:,:));
    subplot(2,1,1);plot(lamdraws_i');title(['prior ',num2str(prior),': lam est wo trafo, i_sel=',num2str(i_sel)],'Interpreter','none');legend(legend_str_vec);
    i_sel2=round(N*3/4);
    lamdraws_i=squeeze(lamdraws(i_sel2,:,:));
    subplot(2,1,2);plot(lamdraws_i');title(['prior ',num2str(prior),': lam est wo trafo, i_sel=',num2str(i_sel2)],'Interpreter','none');legend(legend_str_vec);
    % store figure
    fig_str=['fig_',modspec_string,'_lamdraws_examples'];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
    %
    figure;newplot;
    t_sel=round(T*1/4); % cross section index for lam(i_sel,nf) with factor nf to be plotted
    fdraws_sel=squeeze(fdraws(t_sel,:,:));
    subplot(2,1,1);plot(fdraws_sel');title(['prior ',num2str(prior),': f est wo trafo, t_sel=',num2str(t_sel)],'Interpreter','none');legend(legend_str_vec);
    t_sel=round(T*3/4);
    fdraws_sel=squeeze(fdraws(t_sel,:,:));
    subplot(2,1,2);plot(fdraws_sel');title(['prior ',num2str(prior),': f est wo trafo, t_sel=',num2str(t_sel)],'Interpreter','none');legend(legend_str_vec);
    % store figure
    fig_str=['fig_',modspec_string,'_fdraws_examples'];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
end
end

%
% fig: hist of all lam
%
nshow=5;
nfig=ceil(N/nshow);
for k=1:nfig
    index_var=(k-1)*nshow+1:(k-1)*nshow+nshow;
    if index_var(end)>N
        index_var=(k-1)*nshow+1:N;
    end
    index_var_str=[num2str(index_var(1)),'to',num2str(index_var(end))];
    jj=1;
    figure;newplot;
    for i=1:length(index_var)
        index_sel=index_var(i);
        for j=1:nf
            subplot(nshow,nf,jj);
            hist(squeeze(lamdraws(index_sel,j,:)),50);
            set(gca,'FontSize',8);
            title(['f ',num2str(j),', var ',num2str(index_sel)],'FontSize',8);
            jj=jj+1;
        end
    end
    % store figure
    fig_str=['fig_',modspec_string,'_lamdrawshist','_var',index_var_str];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
end
    
%
% fig: corr of final lam, f draw versus all other draws
% 
% corr f draws
r2mat_fac=nan(n_it-1,nf);r2mat_fac_cross=nan(nf*(nf-1)/2,n_it-1);r2mat_fac_cross_name_str=cell(nf*(nf-1)/2,1);
for j=1:n_it-1
    kk=1;
    for nf_index=1:nf
        r2_fac=corrcoef([squeeze(fdraws(:,nf_index,end)),squeeze(fdraws(:,nf_index,j))]);
        r2mat_fac(j,nf_index)=r2_fac(1,2);
        for k=1:nf
            if nf_index>k
                r2_fac_cross=corrcoef([squeeze(fdraws(:,nf_index,end)),squeeze(fdraws(:,k,j))]);
                r2mat_fac_cross(kk,j)=r2_fac_cross(1,2);
                if j==1
                    name_r2_str=['r',num2str(nf_index),'c',num2str(k)];
                    r2mat_fac_cross_name_str{kk,1}=name_r2_str;
                end
                kk=kk+1;
            end
        end
    end
end
r2mat_fac_cross=r2mat_fac_cross';
flag_fig='on';
if strcmp(flag_fig,'on')
    % own corr
    figure; newplot;
    plot(r2mat_fac);
    v = axis;
    axis([v(1) v(2) -1.0 1.0]);
    title('pearson corr of f(:,:,end) and f(:,:,1:end-1)');
    fig_str=['fig_',modspec_string,'_fdraws_own'];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
    % cross corr
    figure; newplot;
    n_sub=size(r2mat_fac_cross,2);
    for j=1:n_sub
        subplot(n_sub,1,j);
        plot(r2mat_fac_cross(:,j));
        title(['pearson corr across factors f(:,i,end) and f(:,j,1:end-1): ',r2mat_fac_cross_name_str{j,1}]);
        v = axis;
        axis([v(1) v(2) -1.0 1.0]);
    end
    fig_str=['fig_',modspec_string,'_fdraws_cross'];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
end
clear r2mat_fac r2mat_fac_cross
close all
% corr lam draws
r2mat_lam=nan(n_it-1,nf);r2mat_lam_cross=nan(nf*(nf-1)/2,n_it-1);r2mat_lam_cross_name_str=cell(nf*(nf-1)/2,1);
for j=1:n_it-1
    kk=1;
    for nf_index=1:nf
        r2_lam=corrcoef([squeeze(lamdraws(:,nf_index,end)),squeeze(lamdraws(:,nf_index,j))]);
        r2mat_lam(j,nf_index)=r2_lam(1,2);
        for k=1:nf
            if nf_index>k
                r2_lam_cross=corrcoef([squeeze(lamdraws(:,nf_index,end)),squeeze(lamdraws(:,k,j))]);
                r2mat_lam_cross(kk,j)=r2_lam_cross(1,2);
                if j==1
                    name_r2_str=['r',num2str(nf_index),'c',num2str(k)];
                    r2mat_lam_cross_name_str{kk,1}=name_r2_str;
                end
                kk=kk+1;
            end
        end
    end
end
r2mat_lam_cross=r2mat_lam_cross';
flag_fig='on';
if strcmp(flag_fig,'on')
if strcmp(flag_longsmall,'huge')
    % own corr
    figure; newplot;
    plot(r2mat_lam);
    v = axis;
    axis([v(1) v(2) -1.0 1.0]);
    title('pearson corr of lam(:,:,end) and lam(:,:,1:end-1)');
    fig_str=['fig_',modspec_string,'_lamdraws_own'];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
    % cross corr
    figure; newplot;
    n_sub=size(r2mat_lam_cross,2);
    for j=1:n_sub
        subplot(n_sub,1,j);
        plot(r2mat_lam_cross(:,j));
        title(['pearson corr across lam lam(:,i,end) and lam(:,j,1:end-1): ',r2mat_lam_cross_name_str{j,1}]);
        v = axis;
        axis([v(1) v(2) -1.0 1.0]);
    end
    fig_str=['fig_',modspec_string,'_lamdraws_cross'];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
end
end
clear r2mat_lam r2mat_lam_cross
close all

%
% fig: inclusion prob mhpd mah over distinct sample regions
%
vec_zero=zeros(1,nf);
clev=0.95;
method_str='mah';
inclprobdelta_mah_index=nan(N,n_it);
n_sampleparts=4;
repstep=floor(n_it/n_sampleparts);
repindex=round(linspace(1,n_it,n_sampleparts+1));
for repselindex=1:length(repindex)-1
    if repselindex<length(repindex)-1
        repsel=repindex(repselindex):repindex(repselindex+1)-1;
    else
        repsel=repindex(repselindex):repindex(end);
    end
    for i=1:N
        if nf==1 
            lami=squeeze(lamdraws(i,:,repsel));
        else
            lami=squeeze(lamdraws(i,:,repsel))';
        end
        disp_flag='off';fig_flag='off';
        [zeroout_flag,pval_mah]=f_mhpd_eucmah(lami,clev,method_str,disp_flag,fig_flag,vec_zero);
        if zeroout_flag==1
            % lami ci excludes zero in at least in one direction (==nf in all directions)
            inclprobdelta_mah_index(i,repsel(1))=1;
        else
            inclprobdelta_mah_index(i,repsel(1))=0;
        end
    end
end
inclprobdelta_mah_index_sum=sum(inclprobdelta_mah_index,1);
inclprobdelta_mah_index_show=inclprobdelta_mah_index;
inclprobdelta_mah_index_show2=reshape(inclprobdelta_mah_index_show(not(isnan(inclprobdelta_mah_index_show))),N,size(inclprobdelta_mah_index_show(not(isnan(inclprobdelta_mah_index_show))),1)/N);
flag_fig='on';
if strcmp(flag_fig,'on')
if strcmp(flag_longsmall,'huge')
    % avg no of included series
    figure;newplot;
    plot(inclprobdelta_mah_index_sum,'ok')
    v=axis;
    axis(gca,[v(1) v(2) 0 N]);
    title(['prior ',num2str(prior),': average number of included variables for subsamples (window ',num2str(repstep),' of ',num2str(n_it),')']);
    fig_str=['fig_',modspec_string,'_inclprob_mhpdmah_subdraws_avg'];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
    % individual incl probs
    figure;newplot;
    heatmap(inclprobdelta_mah_index_show2,[1:size(inclprobdelta_mah_index_show2,2)],[1:N],[],'Colormap',flipud(gray(50)),'Colorbar',true,'FontSize',2);
    title(['prior ',num2str(prior),': index in/out for each variables for subsamples (window ',num2str(repstep),' of ',num2str(n_it),')']);
    fig_str=['fig_',modspec_string,'_inclprob_mhpdmah_subdraws_indi'];
    set(gcf,'name',fig_str);
    save_fig_str=[folder,fig_str];
    saveas(gcf,save_fig_str);
end
end
close all

%
% figs and tables: acf, geweke test for lamdraw, fdraw
%
flag_conv='on';
if strcmp(flag_conv,'on')
    lamdraws_stack=reshape(lamdraws,N*nf,n_it);
    lamdraws_stack=lamdraws_stack';
    fdraws_stack=reshape(fdraws,T*nf,n_it);
    fdraws_stack=fdraws_stack';
    for j=1:2
        if j==1; statmc_stack=lamdraws_stack;statmc_str='lamdraws';nobs=N; end
        if j==2; statmc_stack=fdraws_stack;statmc_str='fdraws';nobs=T; end
        % autocorrelations
        nlagmax=150;acfout=zeros(nlagmax,nobs*nf);
        for i=1:nobs*nf
            acfout(:,i)=f_sacf(statmc_stack(:,i),nlagmax,1);
        end
        acfmat=zeros(nobs*nf,3);
        acfmat(:,1)=acfout(10,:)';acfmat(:,2)=acfout(50,:)';acfmat(:,3)=acfout(100,:)'; % pull out sacf's at lags 10,50,100
        flag_fig='on';
        if strcmp(flag_fig,'on')
            % boxplot
            figure;newplot;
            selrep=nan(1,nlagmax); % size acfmat = nlagmax,nobs*nf
            selrepindex=[1,1:10:nlagmax,nlagmax];selrepindex=unique(selrepindex);
            selrep(1,selrepindex)=selrepindex;
            boxplot(acfout',selrep,'labels',num2cell(selrepindex));
            title(['prior ',num2str(prior),': acf of ',statmc_str,' (max lag: ',num2str(nlagmax),')']);
            fig_str=['fig_',modspec_string,'_acf_',statmc_str];
            set(gcf,'name',fig_str);
            save_fig_str=[folder,fig_str];
            saveas(gcf,save_fig_str);
        end
        clear acfout
        disp(' ');
        disp(['conv check for ',statmc_str]);
        disp('autocorrelations (at lags 10,50,100: number close to zero at all lags means close to independence)');
        disp([' prior',num2str(prior),': max       ',num2str(max(acfmat,[],1),'%5.2f')]);
        disp([' prior',num2str(prior),': 90prctile ',num2str(prctile(acfmat,90),'%5.2f')]);
        disp([' prior',num2str(prior),': 80prctile ',num2str(prctile(acfmat,80),'%5.2f')]);
        disp('ten highest autocorrelations (average ac over lags 10,50,100)');
        [~,index_max]=sort(mean(acfmat,2),1,'descend'); 
        index_max=index_max(1:20);
        nf_fromindex=ceil(index_max./nobs);
        obs_fromindex=index_max-(nf_fromindex-1)*nobs;
        results=[transpose(1:20),obs_fromindex,nf_fromindex,acfmat(index_max,:)];
        if j==1; disp('rank, i, nf, acf(10,50,100)'); end
        if j==2; disp('rank, t, nf, acf(10,50,100)'); end
        disp(results);
        % geweke conv stat pvals 
        index_first=1:round(n_it*3/10);
        index_last=round(n_it*5/10)+1:size(statmc_stack,1);
        resm1=f_momentg(statmc_stack(index_first,:));
        resm2=f_momentg(statmc_stack(index_last,:));
        geweke_res=f_apm(resm1,resm2);
        pvalmat=cat(1,geweke_res.prob); 
        pvalmat=pvalmat(:,3); % choose taper 10 pct of sample, taper options: 0,5,10,15 pct of sample
        disp(' ');
        disp(['conv check for ',statmc_str]);
        disp('geweke conv stat pvals (large pval: cannot reject the null of same subsample means)');
        disp([' prior',num2str(prior),': min       ',num2str(min(pvalmat,[],1),'%5.2f')]);
        disp([' prior',num2str(prior),': 10prctile ',num2str(prctile(pvalmat,10),'%5.2f')]);
        disp([' prior',num2str(prior),': 20prctile ',num2str(prctile(pvalmat,20),'%5.2f')]);
        disp('ten lowest pvals geweke');
        [~,index_min]=sort(pvalmat,1,'ascend'); % min pval first (equal subsample distr rejected)
        index_min=index_min(1:20);
        nf_fromindex=ceil(index_min./nobs);
        obs_fromindex=index_min-(nf_fromindex-1)*nobs;
        results=[transpose(1:20),index_min,obs_fromindex,nf_fromindex,pvalmat(index_min,:)];
        if j==1; disp('rank, i, nf, pval geweke'); end
        if j==2; disp('rank, t, nf, pval geweke'); end
        disp(results);
        flag_fig='on';
        if strcmp(flag_fig,'on')
            figure;newplot;
            hist(pvalmat(:,:),10)
            title(['prior ',num2str(prior),': hist of geweke conv stat pval based on ',statmc_str]);
            fig_str=['fig_',modspec_string,'_geweke_',statmc_str];
            set(gcf,'name',fig_str);
            save_fig_str=[folder,fig_str];
            saveas(gcf,save_fig_str);
        end
    end
end
diary off

return




% kmedoids clust
[lamdraws_out,fdraws_out,clust_indices,sign_index,clust_indices2]=f_colchange_fbased(lamdraws_raw,fdraws_raw,'on');
clust_indices2a=reshape(clust_indices,r,n_it);
n_it_clust=size(lamdraws_out,3);
n_it=n_it_clust;
disp(['rep after clust ',num2str(n_it_clust)]);

lamdraws=lamdraws_out;
fdraws=fdraws_out;

figure;newplot;
lamdraws_i=squeeze(lamdraws(i_sel,:,squeeze(find(~isnan(lamdraws(i_sel,1,:))))));
subplot(2,1,1);plot(lamdraws_i');title(['clustered: lam, i_sel=',num2str(i_sel)],'Interpreter','none');legend(legend_str_vec);
subplot(2,1,2);plot(clust_indices2');title('cluster index','Interpreter','none');legend(legend_str_vec);

% figures for lamspar out of estimation wo col change correction
nshow=10;
index_var=35+1:35+nshow;
ii=1;
figure;newplot;
for i=1:nshow
    index_sel=index_var(i);
    for j=1:r
        subplot(nshow,r,ii);
        hist(squeeze(lamdraws_out(index_sel,j,:)),50);
        legend_str=['clust: f ',num2str(j),', var ',num2str(index_sel)];
        title(legend_str,'Interpreter','none');
        set(gca,'FontSize',8);
        ii=ii+1;
    end
end

fdraws=squeeze(fdraws(:,:,squeeze(find(~isnan(fdraws(1,1,:))))));
r2mat_fac=nan(n_it-1,r);
for r_index=1:r
    r2_fac=corrcoef([squeeze(fdraws(:,r_index,end)),squeeze(fdraws(:,r_index,1:end-1))]);
    r2mat_fac(:,r_index)=r2_fac(1,2:end)';
end
figure; newplot;
plot(r2mat_fac);
v = axis;
axis([v(1) v(2) -1.0 1.0]);
title('after clustering: pearson corr of f(:,:,end) and f(:,:,1:end-1)');

acfmat=nan(N*r,2); 
pvalmat=nan(N*r,4); 
for i=1:N
    lamdraws_i=squeeze(lamdraws(i,:,squeeze(find(~isnan(lamdraws(i,1,:))))));
    lamdraws_i=lamdraws_i';
    % autocorrelations
    nlagmax=50;acfout_i=zeros(nlagmax,r);
    for j=1:r
        acfout_i(:,j)=f_sacf(lamdraws_i(:,j),nlagmax,1);
    end
    acfmat_i=zeros(r,2);
    acfmat_i(:,1)=acfout_i(5,:)';acfmat_i(:,2)=acfout_i(10,:)'; % pull out sacf's at lags 5,10
    acfmat(r*(i-1)+1:r*(i-1)+r,:)=acfmat_i;   
    % geweke
    index_first=1:round(n_it*3/10);
    index_last=round(n_it*5/10)+1:size(lamdraws_i,1);
    resm1=f_momentg(lamdraws_i(index_first,:));
    resm2=f_momentg(lamdraws_i(index_last,:));
    geweke_res=f_apm(resm1,resm2);
    pvalmat(r*(i-1)+1:r*(i-1)+r,:)=reshape(cat(2,geweke_res.prob),4,1*r)';
end
pvalmat=pvalmat(:,3); % choose taper 10 pct of sample, taper options: 0,5,10,15 pct of sample

disp(' ');
disp('autocorrelations after clust (at lags 5,10: number close to zero at all lags means close to independence)');
disp([' prior',num2str(prior),': max       ',num2str(max(acfmat,[],1),'%5.2f')]);
disp([' prior',num2str(prior),': 90prctile ',num2str(prctile(acfmat,90),'%5.2f')]);
disp([' prior',num2str(prior),': 80prctile ',num2str(prctile(acfmat,80),'%5.2f')]);
disp(' ');
disp('geweke conv stat pvals after clust (large pval: cannot reject the null of same subsample means)');
disp([' prior',num2str(prior),': min       ',num2str(min(pvalmat,[],1),'%5.2f')]);
disp([' prior',num2str(prior),': 10prctile ',num2str(prctile(pvalmat,10),'%5.2f')]);
disp([' prior',num2str(prior),': 20prctile ',num2str(prctile(pvalmat,20),'%5.2f')]);
figure;newplot;
hist(pvalmat,10)
title(['prior ',num2str(prior),': hist of geweke conv stat pval']);    
disp(' ');

results=[];
results.lamdraws=lamdraws;
results.fdraws=fdraws;
results.clust_indices=clust_indices;
results.sign_index=sign_index;
res_string = ['results_',flag_rollrec(1,1:3),'_k',num2str(nf), ...
              '_prior',num2str(prior),'_utz',num2str(utz), ...
              '_enddate',num2str(end_sample_date_rec),'_clust'];
str = ([base_dir 'results\' res_string]);
save(str,'results');
