function [ftmcstar_out,lamstarmc_out,it_sel]=f_identify_factors_new(ftmcstar,lamstarmc,prior)
%factor identification:
% 1. collect the highly correlated factor simulations (the number of correlated draws should be larger than sigdr*Ndraws, sigdr=0.05)
%      to form a first mean of common patterns at each 'factor place'
%    Define: cor_lev: the minimum correlation to group draws to a pattern, and then to group patterns across factor places
%            cor_bnd: the lowest correlation to group patterns across factor places
% 2. collect all patterns highly correlated across 'factor place'
%     (i) minimum correlation of cor_lev to group patterns across factor places
%     (ii) if no patterns are correlated, decrease the correlation level successively by 0.1 to cor_bnd to group patterns 
%     (iii) group patterns across factor places (adjust for correlation sign) to obtain estimates of nf estimated factor patterns  
% 3. if the number of extracted patterns is higher than the number of estimated factors: reduce those patterns which are most correlated with
%     other ones (to keep mostly independent factor patterns
%
% the factor patterns are saved in ftstmed (T x nf)
% if the number of patterns has to be reduced to nf, the patterns are saved into ftstmed_red

% lamstarmc=lamsparmc;
% ftmcstar=ftstarmc;
perm=1;
nf=size(lamstarmc,2);
MMC=size(lamstarmc,3);
T=size(ftmcstar,1);

cor_lev=0.8;
cor_bnd=0.5;

factors=[1:nf];
%it_ref=zeros(1,nf);
mit=MMC;
it0=0;
int=ceil((MMC-it0)/mit);
index=[it0+1:int:MMC];
n_med=length(index);

sigdr=n_med*0.01;

ind_med=1:n_med;
it_ref=struct([]);
sel=struct([]);
it_sel=struct([]);
c_mat=struct([]);fac_ind=struct([]);


% 1. collect the highly correlated factor simulations to form a first mean of common patterns at each 'factor place'
% (the number of correlated draws should be larger than sigdr*Ndraws, sigdr=0.05)
ftst=struct([]);
for k=1:nf
    ind_med=index;
    r=1;
    cr=1;
    ftst(k).co=ones(length(index),10)*NaN;
    while length(ind_med)>1
        co_mat=corr(ftmcstar(:,k,ind_med(end)),permute(ftmcstar(:,k,ind_med),[1 3 2])); % row of r^2     
        ftst(k).co(1:length(co_mat),cr)=co_mat';cr=cr+1;%disp(['cr ',num2str(cr)]);
        %figure(1);plot(co_mat');title('co_mat1');
        %pause
        ind_co=abs(co_mat)>cor_lev;
        while (sum(ind_co)<=sigdr)
            %disp(['sum(ind_co) ',num2str(sum(ind_co)),', sigdr ',num2str(sigdr)]);
            ind_med(ind_co)=0; % pick the rest not covered by previous pattern
            ind_med=ind_med(find(ind_med));           
            if length(ind_med)<=1
                break
            end
            co_mat=corr(ftmcstar(:,k,ind_med(end)),permute(ftmcstar(:,k,ind_med),[1 3 2]));
            ftst(k).co(:,cr)=nan(length(index),1);%clean for shorter co
            ftst(k).co(1:length(co_mat),cr)=co_mat';cr=cr+1;%disp(['cr ',num2str(cr)]);
            %figure(2);plot(co_mat');title('co_mat2');
            %pause
            ind_co=abs(co_mat)>cor_lev;
        end
        if length(ind_med)<=1
            break
        end
        ftst(k).pat(:,r)=mean(permute(ftmcstar(:,k,ind_med(ind_co)),[1 3 2]).*kron(ones(T,1),sign(co_mat(ind_co))),2);
        %figure(3);plot(ftst(k).pat);title('ftst(k).pat');
        %pause
        ind_med(ind_co)=0;
        ind_med=ind_med(find(ind_med));
        r=r+1;
    end
end
disp(['r ',num2str(r)]);
for i=1:nf
    figure(i);plot(ftst(i).pat);title(['ftst(',num2str(i),').pat']);
end
%pause

% 2. collect all patterns highly correlated across 'factor place'
ftstmed=[];
ftstpat=[];
for k=1:size(ftst,2)
    ftstpat=cat(2,ftstpat,ftst(k).pat);
end
ind_med=1:size(ftstpat,2);
while length(ind_med)>1
    
    co_mat=corr(ftstpat(:,ind_med));
    co_mat
    pause
    ind_co=abs(co_mat)>cor_lev;
    if perm==2
        while all(sum(ind_co,1)==1)
            cor_lev=cor_lev-0.1;
            ind_co=abs(co_mat)>cor_lev;
        end
        if cor_lev<cor_bnd
            break
        end
    elseif perm==1
        if any(sum(ind_co,1)==1) % if only one co is greater than cor_lev
            ftstmed=cat(2,ftstpat(:,ind_med(sum(ind_co,1)==1)),ftstmed); % cat pattern with only one co greater than cor_lev
            ind_med(sum(ind_co,1)==1)=0;
            ind_med=find(ind_med);
            if length(ind_med)<=1
                break
            end
            co_mat=corr(ftstpat(:,ind_med));
            ind_co=abs(co_mat)>cor_lev;
        end
    end
    
    co_ref=find(sum(ind_co,1)==max(sum(ind_co,1))); % index for col with most co entries greater than cor_lev
    ii=find(ind_co(:,co_ref(1)))';% find(all(ind_co(:,ones(1,lco))==ind_co,1));
    ftstmed=cat(2,mean(ftstpat(:,ind_med(ii)).*kron(ones(T,1),sign(co_mat(co_ref(1),ii))),2),ftstmed);
    ind_med(ii)=0;
    ind_med=ind_med(find(ind_med));
    
end
size(ftstmed)
figure(nf+1);plot(ftstmed);title('ftstmed');
% pause

% so far, the draws are not permuted and not adjusted for sign switching
% the output is stored in ftstmed (T x factor patterns)
% 
% if the number of factor patterns is equal to the number of estimated factors, run permute_factors_new
% if the number of factor patterns is smaller than the number of estimated factors, run permute_factors_new_ext
%     
% the permuted output is stored in the original matrices (lamstarmc, ftmcstar), and it_sel.in contains the 
% index of retained draws, i.e. the draws with permutations of draws uniquely assigned to factor patterns
%
% retained draws are permuted and adjusted for sign sitching. The factors are ordered in descending number 
% of non-zero factor loadings.
if size(ftstmed,2)>nf
    disp('size(ftstmed,2)>nf');
    [ftmcstar_out,lamstarmc_out,it_sel]=f_permute_factors_group(ftmcstar,lamstarmc,ftstmed);
end
if size(ftstmed,2)==nf
    disp('size(ftstmed,2)==nf');
    [ftmcstar_out,lamstarmc_out,it_sel]=f_permute_factors_new(ftmcstar,lamstarmc,ftstmed,prior);
end
if size(ftstmed,2)<nf
    disp('size(ftstmed,2)<nf');
    [ftmcstar_out,lamstarmc_out,it_sel]=f_permute_factors_new_ext(ftmcstar,lamstarmc,ftstmed,prior);
end

% close all

end

